@@ -18,14 +18,15 @@ For more information, see http://vispy.org.
 """
 
 from __future__ import division
+from pkg_resources import get_distribution, DistributionNotFound
 
 __all__ = ['use', 'sys_info', 'set_log_level', 'test']
 
-# Definition of the version number
-version_info = 0, 6, 1  # , 'dev0'  # major, minor, patch, extra
-
-# Nice string for the version (mimic how IPython composes its version str)
-__version__ = '-'.join(map(str, version_info)).replace('-', '.').strip('-')
+try:
+    __version__ = get_distribution(__name__).version
+except DistributionNotFound:
+    # package is not installed
+    pass
 
 from .util import config, set_log_level, keys, sys_info  # noqa
 from .util.wrappers import use  # noqa
